.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "0.12",
.\"     date            = "03 June 2005",
.\"     time            = "09:52:34 MDT",
.\"     filename        = "biborder.man",
.\"     address         = "University of Utah
.\"                        Department of Mathematics, 110 LCB
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "60915 445 1757 12371",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@computer.org (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "bibliography, BibTeX, ordering",
.\"     supported       = "yes",
.\"     docstring       = "This file contains the UNIX manual pages
.\"                        for the biborder utility, a program for
.\"                        ordering key fields in BibTeX bibliography
.\"                        files.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.if t .ds Bi B\s-2IB\s+2T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Bi BibTeX
.if t .ds Te T\\h'-0.1667m'\\v'0.20v'E\\v'-0.20v'\\h'-0.125m'X
.if n .ds Te TeX
.TH BIBORDER 1 "03 June 2005" "Version 0.12"
.\"======================================================================
.SH NAME
biborder \- order key fields in a BibTeX bibliography file
.\"======================================================================
.SH SYNOPSIS
.B biborder
.RB [ \-alphabetical ]
.RB [ \-bimonthly
.IR m1/m2/m3/m4/m5/m6 ]
.if n .ti +9n
.RB [ \-check-missing ]
.RB [ \-help ]
.RB [ \-isbn-13 ]
.RB [ \-monthly ]
.if n .ti +9n
.if t .ti +.5i
.RB [ \-quarterly
.IR m1/m2/m3/m4 ]
.RB [ \-version ]
.if n .ti +9n
.if t .ti +.5i
< infile > outfile
.nf
or
.fi
.B biborder
.RB [ \-alphabetical ]
.RB [ \-bimonthly
.IR m1/m2/m3/m4/m5/m6 ]
.if n .ti +9n
.RB [ \-check-missing ]
.RB [ \-help ]
.RB [ \-isbn-13 ]
.RB [ \-monthly ]
.if n .ti +9n
.if t .ti +.5i
.RB [ \-quarterly
.IR m1/m2/m3/m4 ]
.RB [ \-version ]
BibTeXfile(s)
.if n .ti +9n
.if t .ti +.5i
> outfile
.\"======================================================================
.SH DESCRIPTION
.B biborder
filters one or more \*(Bi\& bibliographies, or
bibliography fragments, from the specified files,
or from its standard input if no filenames are
provided, printing on standard output a
bibliography in which key fields have been put
into a standard order:
.IR author ,
.IR editor ,
.IR key ,
.IR booktitle ,
.IR title ,
.IR crossref ,
.IR chapter ,
.IR journal ,
.IR volume ,
.IR type ,
.IR number ,
.IR howpublished ,
.IR institution ,
.IR organization ,
.IR publisher ,
.IR school ,
.IR address ,
.IR edition ,
.IR pages ,
.IR day ,
.IR month ,
.IR year ,
.IR CODEN ,
.IR EAN ,
.IR ISBN ,
.IR ISBN-13 ,
.IR ISSN ,
.IR LCCN ,
.IR MRclass ,
.IR MRnumber ,
.IR MRreviewer ,
.IR bibdate ,
.IR bibsource ,
.IR note ,
.IR price ,
.IR series ,
and
.IR URL .
All other key fields are output in alphabetical
order following the standard ones.
.PP
A consistent key field order makes \*(Bi\& entries
easier to read, and also facilitates
identification and removal of duplicates, such as
with
.BR "bibsort -u" .
.\"======================================================================
.SH OPTIONS
Command-line options may be abbreviated to a
unique leading prefix.
.PP
To avoid confusion with options, if a filename
begins with a hyphen, it must be disguised by a
leading absolute or relative directory path, e.g.
.I /tmp/-foo.bib
or
.IR ./-foo.bib .
.\"-----------------------------------------------
.TP \w'\-check-missing'u+3n
.B \-alphabetical
Output all keys in strict alphabetical order,
rather than in the standard order given
previously.
.\"-----------------------------------------------
.TP
.BI \-bimonthly " m1,m2,m3,m4,m5,m6"
If this option is specified, all of the journals
in the \*(Bi\& file entries are assumed to appear
at two-month intervals. The six month names that
correspond to each such interval must be given as
a
.I single
argument following
.BR \-bimonthly ,
with the names separated by (any number of)
non-letters.  A typical example is
.IR feb-apr-jun-aug-oct-dec ,
specifying that issue number 1 appears in
February, and number 6 in December.
.\"-----------------------------------------------
.TP
.B \-check-missing
If this option is specified, missing expected key
fields will be supplied, with the key field name
prefixed with OPT, and the value string set to a
pair of question marks, e.g.
.nf
  OPTvolume =    "??",
.fi
The
.I OPT
prefix ensures that the key is ignored by \*(Bi\&,
so that the question marks will not appear in an
output
.I .bbl
file.  The GNU Emacs
.I bibtex-mode
editing support has functions for removing the OPT
prefixes, and so does
.BR bibclean (1).
.IP
The doubled question marks are distinguished from
single ones that might legitimately appear in
value strings, and also serve as a convenient
regular-expression pattern for
.BR bibextract (1),
allowing easy preparation of a printed listing of
just those entries that have incomplete
bibliographic data:
.nf
.BI "     bibextract" " '' '[?][?]' BibTeXfiles " "|  lpr"
.fi
.\"-----------------------------------------------
.TP
.B \-isbn-13
Because the 10-digit
.I "International Standard Book Number"
(ISBN) system introduced in 1972 is running out of
assignable numbers, effective 2007-01-01, it is
replaced by a new 13-digit system based on the
.I "European Article Numbering"
(EAN) system.  The name for the new system is
ISBN-13, and such values are also EAN values.
.IP
The 12-digit Uniform Product Code (UPC)
transitioned to the EAN-13 system on 2005-01-01,
.IP
Both the ISBN and UPC numbers appear on printed
books produced since those systems were
introduced, but library catalogs normally record
only ISBN data, not UPC values.
.IP
ISBN-13 translations of ISBN-10 data consist of
the prefix \fC978-\fP followed by the first 9
digits of the ISBN-10 value with the same
(optional) hyphenation as before, followed by a
hyphen and a new check digit.  The latter is
computed by a different algorithm, and will not in
general match the tenth digit (the check digit) of
the ISBN-10 value.
.IP
As an aid to converting \*(Bi\& files with ISBN
data to the new format, the
.B \-isbn-13
option requests that
.B biborder
generate companion ISBN-13 key/value pairs,
provided that an ISBN-13 key does not already
exist, and that ISBN values are properly
hyphenated.  Existing ISBN assignments are
preserved, and the ISBN numbers are merely
converted for use in a new key/value pair.  Thus,
an input assignment
.nf
    \fCISBN =    "1-55798-243-0 (hardcover),
               1-55798-241-4 (paperback)",\fP
.fi
on output becomes
.nf
    \fCISBN =    "1-55798-243-0 (hardcover),
               1-55798-241-4 (paperback)",\fP
    \fCISBN-13 = "978-1-55798-243-8 (hardcover),
               978-1-55798-241-4 (paperback)",\fP
.fi
.IP
More information on the changes to the ISBN system
can be found on the Web at:
.nf
    \fChttp://www.ariadne.ac.uk/issue41/chapman/intro.html\fP
    \fChttp://www.collectionscanada.ca/iso/tc46sc9/isbn.htm\fP
    \fChttp://www.bisg.org/pi/\fP
    \fChttp://www.bisg.org/isbn-13/ISBN13_For_Dummies.pdf\fP
    \fChttp://www.isbn.org/\fP
\fP
.fi
.IP
At some future time, EAN identifiers will grow to
14 digits and be called a
.IR "Global Trade Identifier Number" :
a new leading digit will provide for a ten-fold
expansion in the number of available identifiers.
For details, see:
.nf
    \fChttp://www.gtin.info/\fP
\fP
.fi
.\"-----------------------------------------------
.TP
.B \-monthly
If this option is specified, all of the journals
in the \*(Bi\& file entries are assumed to appear
monthly, 1 in January, 2 in February, .\|.\|., 12
in December.
.IP
If only one of the number and month values is
supplied,
.B biborder
will supply the other automatically, but will
name it
.I OPTmonth
or
.I OPTnumber
to distinguish it from existing keys.  A simple
editor string substitution, or
.BR bibclean (1),
can subsequently normalize the appearance.
.\"-----------------------------------------------
.TP
.BI \-quarterly " m1,m2,m3,m4"
If this option is specified, all of the journals
in the \*(Bi\& file entries are assumed to appear
quarterly. The four month names that correspond to
each quarter must be given as a
.I single
argument following
.BR \-quarterly ,
with the names separated by (any number of)
non-letters.  Some examples are
.IR jan-apr-jul-oct ,
.IR mar////jun.sep:dec ,
.IR "Spring\e Summer\e Fall\e Winter" ,
and
.IR "'Spring Summer Fall Winter'" .
The last two examples show that when space
separators are used, they must be backslashed, or
else the list must be surrounded by quotes, to
force UNIX shells to interpret the quarter names
as a single argument.
.\"-----------------------------------------------
.PP
The options
.BR \-bimonthly ,
.BR \-monthly ,
and
.B \-quarterly
are mutually exclusive;
.B biborder
will refuse to run if more than one of them is
specified; they should normally only be used in
journal-specific bibliographies, since
number-month pairing does not hold for all
journals.
.PP
Failure to supply the correct number of month
names for
.B \-bimonthly
or
.B \-quarterly
will also cause immediate termination.
.\"======================================================================
.SH "WARNING AND ERROR MESSAGES"
.B biborder
will issue warning messages in the following cases:
.TP \w'\(bu'u+1n
\(bu
With
.BR \-check-missing ,
for unrecognized \*(Bi\& entry types.  The entry will
be output without checking for missing key
names.
.TP
\(bu
With
.BR \-bimonthly ,
.BR \-monthly ,
and
.BR \-quarterly ,
for mismatches between
.I month
and
.I number
values, or for an out-of-range
.I number
value.
.TP
\(bu
For duplicate key names.  Such key/value pairs are
sorted together by name, preserving their original order.
.PP
.B biborder
will issue an error message and terminate with
exit code 1, and incomplete output, in the
following cases:
.TP \w'\(bu'u+1n
\(bu
For an unrecognized command-line argument (only
the first letter of each option is currently
examined).
.TP
\(bu
If more than one of
.BR \-bimonthly ,
.BR \-monthly ,
and
.B \-quarterly
is specified.
.TP
\(bu
End-of-file is reached while collecting an entry.
.TP
\(bu
A line beginning with `@' is encountered while
collecting an entry, before balanced braces have
been found.
.TP
\(bu
An incorrect number of month names is specified
with
.B \-bimonthly
or
.BR \-quarterly .
.\"======================================================================
.SH CAVEATS
\*(Bi\& has loose syntactical requirements that
the current simple implementation of
.B biborder
does not support.  In particular, outer
parentheses may
.I not
be used in place of braces following ``@keyword''
patterns.  If you have such a file, you can use
.BR bibclean (1)
to prettyprint it into a form that
.B biborder
can handle successfully.
.\"======================================================================
.SH "SEE ALSO"
.BR bibcheck (1),
.BR bibclean (1),
.BR bibdup (1),
.BR bibextract (1),
.BR bibjoin (1),
.BR biblabel (1),
.BR biblex (1),
.BR bibparse (1),
.BR bibsort (1),
.BR bibtex (1),
.BR bibunlex (1),
.BR citesub (1),
.BR emacs (1).
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe
University of Utah
Department of Mathematics, 110 LCB
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
Tel: +1 801 581 5254
FAX: +1 801 581 4148
Email: <beebe@math.utah.edu>, <beebe@acm.org>, <beebe@computer.org>
WWW URL: http://www.math.utah.edu/~beebe
.fi
.\"==============================[The End]==============================
